@@ -422,6 +422,16 @@ enum
     NtUserSystemTrayCall      = 0x0306,
     NtUserDragDropCall        = 0x0307,
     NtUserPostDdeCall         = 0x0308,
+    NtUserWintabDriverCall    = 0x0309,
+};
+
+/* NtUserWintabDriverCall codes */
+enum
+{
+    NtUserWintabAttach,
+    NtUserWintabInfo,
+    NtUserWintabInit,
+    NtUserWintabPacket,
 };
 
 /* NtUserThunkedMenuItemInfo codes */
@@ -639,6 +649,7 @@ enum wine_internal_message
     WM_WINE_WINDOW_STATE_CHANGED,
     WM_WINE_UPDATEWINDOWSTATE,
     WM_WINE_TRACKMOUSEEVENT,
+    WM_WINE_SETPIXELFORMAT,
     WM_WINE_FIRST_DRIVER_MSG = 0x80001000,  /* range of messages reserved for the USER driver */
     WM_WINE_CLIPCURSOR = 0x80001ff0, /* internal driver notification messages */
     WM_WINE_SETCURSOR,
@@ -784,7 +795,7 @@ W32KAPI HWND    WINAPI NtUserCreateWindowEx( DWORD ex_style, UNICODE_STRING *cla
                                              UNICODE_STRING *version, UNICODE_STRING *window_name,
                                              DWORD style, INT x, INT y, INT cx, INT cy,
                                              HWND parent, HMENU menu, HINSTANCE instance, void *params,
-                                             DWORD flags, HINSTANCE client_instance, DWORD unk, BOOL ansi );
+                                             DWORD flags, HINSTANCE client_instance, const WCHAR *class, BOOL ansi );
 W32KAPI HWINSTA WINAPI NtUserCreateWindowStation( OBJECT_ATTRIBUTES *attr, ACCESS_MASK mask, ULONG arg3,
                                                   ULONG arg4, ULONG arg5, ULONG arg6, ULONG arg7 );
 W32KAPI HDWP    WINAPI NtUserDeferWindowPosAndBand( HDWP hdwp, HWND hwnd, HWND after, INT x, INT y,
@@ -899,6 +910,7 @@ W32KAPI BOOL    WINAPI NtUserGetUpdatedClipboardFormats( UINT *formats, UINT siz
 W32KAPI BOOL    WINAPI NtUserGetUpdateRect( HWND hwnd, RECT *rect, BOOL erase );
 W32KAPI DWORD   WINAPI NtUserGetWindowContextHelpId( HWND hwnd );
 W32KAPI HDC     WINAPI NtUserGetWindowDC( HWND hwnd );
+W32KAPI BOOL    WINAPI NtUserGetWindowDisplayAffinity( HWND hwnd, DWORD *affinity );
 W32KAPI BOOL    WINAPI NtUserGetWindowPlacement( HWND hwnd, WINDOWPLACEMENT *placement );
 W32KAPI int     WINAPI NtUserGetWindowRgnEx( HWND hwnd, HRGN hrgn, UINT unk );
 W32KAPI BOOL    WINAPI NtUserHideCaret( HWND hwnd );
@@ -922,6 +934,7 @@ W32KAPI INT     WINAPI NtUserMenuItemFromPoint( HWND hwnd, HMENU handle, int x,
 W32KAPI BOOL    WINAPI NtUserMessageBeep( UINT type );
 W32KAPI LRESULT WINAPI NtUserMessageCall( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lparam,
                                           void *result_info, DWORD type, BOOL ansi );
+W32KAPI BOOL    WINAPI NtUserModifyUserStartupInfoFlags( DWORD mask, DWORD flags );
 W32KAPI BOOL    WINAPI NtUserMoveWindow( HWND hwnd, INT x, INT y, INT cx, INT cy, BOOL repaint );
 W32KAPI DWORD   WINAPI NtUserMsgWaitForMultipleObjectsEx( DWORD count, const HANDLE *handles,
                                                           DWORD timeout, DWORD mask, DWORD flags );
@@ -1294,6 +1307,7 @@ enum
     NtUserCallHwnd_IsWindowEnabled,
     NtUserCallHwnd_IsWindowUnicode,
     NtUserCallHwnd_IsWindowVisible,
+    NtUserCallHwnd_SetForegroundWindowInternal,
     /* temporary exports */
     NtUserGetFullWindowHandle,
     NtUserIsCurrentProcessWindow,
@@ -1305,6 +1319,11 @@ static inline void NtUserActivateOtherWindow( HWND hwnd )
     NtUserCallHwnd( hwnd, NtUserCallHwnd_ActivateOtherWindow );
 }
 
+static inline BOOL NtUserSetForegroundWindowInternal( HWND hwnd )
+{
+    return NtUserCallHwnd( hwnd, NtUserCallHwnd_SetForegroundWindowInternal );
+}
+
 static inline void *NtUserGetDialogInfo( HWND hwnd )
 {
     return (void *)NtUserCallHwnd( hwnd, NtUserCallHwnd_GetDialogInfo );
@@ -1386,7 +1405,9 @@ enum
     NtUserCallHwndParam_GetWindowLongW,
     NtUserCallHwndParam_GetWindowLongPtrA,
     NtUserCallHwndParam_GetWindowLongPtrW,
-    NtUserCallHwndParam_GetWindowRects,
+    NtUserCallHwndParam_GetWindowRect,
+    NtUserCallHwndParam_GetClientRect,
+    NtUserCallHwndParam_GetPresentRect,
     NtUserCallHwndParam_GetWindowRelative,
     NtUserCallHwndParam_GetWindowThread,
     NtUserCallHwndParam_GetWindowWord,
@@ -1406,7 +1427,6 @@ enum
 struct get_window_rects_params
 {
     RECT *rect;
-    BOOL client;
     UINT dpi;
 };
 
@@ -1447,8 +1467,14 @@ static inline WORD NtUserGetClassWord( HWND hwnd, INT offset )
 
 static inline BOOL NtUserGetClientRect( HWND hwnd, RECT *rect, UINT dpi )
 {
-    struct get_window_rects_params params = {.rect = rect, .client = TRUE, .dpi = dpi};
-    return NtUserCallHwndParam( hwnd, (UINT_PTR)&params, NtUserCallHwndParam_GetWindowRects );
+    struct get_window_rects_params params = {.rect = rect, .dpi = dpi};
+    return NtUserCallHwndParam( hwnd, (UINT_PTR)&params, NtUserCallHwndParam_GetClientRect );
+}
+
+static inline BOOL NtUserGetPresentRect( HWND hwnd, RECT *rect, UINT dpi )
+{
+    struct get_window_rects_params params = {.rect = rect, .dpi = dpi};
+    return NtUserCallHwndParam( hwnd, (UINT_PTR)&params, NtUserCallHwndParam_GetPresentRect );
 }
 
 struct get_scroll_info_params
@@ -1490,8 +1516,8 @@ static inline LONG NtUserGetWindowLongW( HWND hwnd, INT offset )
 
 static inline BOOL NtUserGetWindowRect( HWND hwnd, RECT *rect, UINT dpi )
 {
-    struct get_window_rects_params params = {.rect = rect, .client = FALSE, .dpi = dpi};
-    return NtUserCallHwndParam( hwnd, (UINT_PTR)&params, NtUserCallHwndParam_GetWindowRects );
+    struct get_window_rects_params params = {.rect = rect, .dpi = dpi};
+    return NtUserCallHwndParam( hwnd, (UINT_PTR)&params, NtUserCallHwndParam_GetWindowRect );
 }
 
 static inline HWND NtUserGetWindowRelative( HWND hwnd, UINT rel )
